@@ -83,7 +83,7 @@ CREATE TABLE groups
 (
     id serial,
     name varchar (100) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -100,8 +100,23 @@ CREATE TABLE group_user
 (
     user_id integer NOT NULL,
     group_id integer NOT NULL,
-    permission_read SMALLINT NOT NULL,
-    permission_write SMALLINT NOT NULL,
+    permission_key VARCHAR (20),
+    permission_value SMALLINT NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by integer NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by integer NOT NULL
+);
+
+-----------------------------------------------------------------------------
+-- group_customer_user
+-----------------------------------------------------------------------------
+CREATE TABLE group_customer_user
+(
+    user_id VARCHAR (40) NOT NULL,
+    group_id integer NOT NULL,
+    permission_key VARCHAR (20),
+    permission_value SMALLINT NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
     change_time timestamp(0) NOT NULL,
@@ -141,7 +156,7 @@ CREATE TABLE charset
     id serial,
     name varchar (200) NOT NULL,
     charset varchar (50) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -158,7 +173,7 @@ CREATE TABLE ticket_state
 (
     id serial,
     name varchar (100) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     type_id smallint NOT NULL,
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
@@ -176,7 +191,7 @@ CREATE TABLE ticket_state_type
 (
     id serial,
     name VARCHAR (120) NOT NULL,
-    comment VARCHAR (250),
+    comments VARCHAR (250),
     create_time timestamp(0) NOT NULL,
     create_by INTEGER NOT NULL,
     change_time timestamp(0) NOT NULL,
@@ -193,7 +208,7 @@ CREATE TABLE salutation
     id serial,
     name varchar (100) NOT NULL,
     text varchar NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -211,7 +226,7 @@ CREATE TABLE signature
     id serial,
     name varchar (100) NOT NULL,
     text varchar NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -232,7 +247,7 @@ CREATE TABLE system_address
     value2 varchar (200), 
     value3 varchar (200),
     queue_id smallint NOT NULL,
-    comment varchar (200),
+    comments varchar (200),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -248,7 +263,7 @@ CREATE TABLE follow_up_possible
 (
     id serial,
     name varchar (100) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -277,7 +292,7 @@ CREATE TABLE queue
     lock_notify smallint NOT NULL,
     state_notify smallint NOT NULL,
     owner_notify smallint NOT NULL,
-    comment varchar (200),
+    comments varchar (200),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -309,10 +324,22 @@ CREATE TABLE ticket
     customer_user_id varchar (250),
     timeout integer,
     until_time integer,
-    freekey1 varchar (150),
+    freekey1 varchar (80),
     freetext1 varchar (150),
-    freekey2 varchar (150),
+    freekey2 varchar (80),
     freetext2 varchar (150),
+    freekey3 varchar (80),
+    freetext3 varchar (150),
+    freekey4 varchar (80),
+    freetext4 varchar (150),
+    freekey5 varchar (80),
+    freetext5 varchar (150),
+    freekey6 varchar (80),
+    freetext6 varchar (150),
+    freekey7 varchar (80),
+    freetext7 varchar (150),
+    freekey8 varchar (80),
+    freetext8 varchar (150),
     valid_id smallint NOT NULL,
     create_time_unix integer NOT NULL,
     create_time timestamp(0) NOT NULL,
@@ -326,6 +353,15 @@ create  INDEX index_ticket_queue_view ON ticket (ticket_state_id, ticket_lock_id
 create  INDEX index_ticket_user ON ticket (user_id);
 create  INDEX index_ticket_answered ON ticket (ticket_answered);
 
+-----------------------------------------------------------------------------
+-- ticket_link
+-----------------------------------------------------------------------------
+CREATE TABLE ticket_link
+(
+    ticket_id_master serial NOT NULL,
+    ticket_id_slave serial NOT NULL
+);
+
 -----------------------------------------------------------------------------
 -- ticket_history
 -----------------------------------------------------------------------------
@@ -354,7 +390,7 @@ CREATE TABLE ticket_history_type
 (
     id serial,
     name varchar (100) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -371,7 +407,7 @@ CREATE TABLE article_type
 (
     id serial,
     name varchar (100) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -388,7 +424,7 @@ CREATE TABLE article_sender_type
 (
     id serial,
     name varchar (100) NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -476,7 +512,7 @@ CREATE TABLE standard_response
     id serial,
     name varchar (80) NOT NULL,
     text varchar NOT NULL,
-    comment varchar (80),
+    comments varchar (80),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -509,7 +545,7 @@ CREATE TABLE standard_attachment
     content_type varchar (150) NOT NULL,
     content varchar NOT NULL,
     filename varchar (250) NOT NULL,
-    comment varchar (150),
+    comments varchar (150),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -541,7 +577,7 @@ CREATE TABLE auto_response_type
 (
     id serial,
     name varchar (50) NOT NULL,
-    comment varchar (80),
+    comments varchar (80),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -563,8 +599,8 @@ CREATE TABLE auto_response
     text2 varchar,
     type_id smallint NOT NULL,
     system_address_id smallint NOT NULL,
-    charset_id smallint NOT NULL,
-    comment varchar (100),
+    charset varchar (80) NOT NULL,
+    comments varchar (100),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -606,25 +642,6 @@ CREATE TABLE time_accounting
 );
 create  INDEX time_accounting_ticket_id ON time_accounting (ticket_id);
 
------------------------------------------------------------------------------
--- faq
------------------------------------------------------------------------------
-CREATE TABLE faq
-(
-    id serial,
-    name varchar (200) NOT NULL,
-    text varchar (255) NOT NULL,
-    language_id smallint NOT NULL,
-    comment varchar (80),
-    valid_id smallint NOT NULL,
-    create_time timestamp(0) NOT NULL,
-    create_by integer NOT NULL,
-    change_time timestamp(0) NOT NULL,
-    change_by integer NOT NULL,
-    PRIMARY KEY(id),
-    UNIQUE (name)
-);
-
 -----------------------------------------------------------------------------
 -- session
 -----------------------------------------------------------------------------
@@ -673,7 +690,7 @@ CREATE TABLE customer_user
     salutation varchar (50),
     first_name varchar (100) NOT NULL,
     last_name varchar (100) NOT NULL,
-    comment varchar (250) NOT NULL,
+    comments varchar (250) NOT NULL,
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -716,7 +733,7 @@ CREATE TABLE pop3_account
     host varchar (200) NOT NULL,
     queue_id integer NOT NULL,
     trusted smallint NOT NULL,
-    comment varchar (250),
+    comments varchar (250),
     valid_id smallint NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by integer NOT NULL,
@@ -725,6 +742,135 @@ CREATE TABLE pop3_account
     PRIMARY KEY(id)
 );
 
+-----------------------------------------------------------------------------
+-- search_profile
+-----------------------------------------------------------------------------
+CREATE TABLE search_profile
+(
+    login varchar (200) NOT NULL,
+    profile_name varchar (200) NOT NULL,
+    profile_key varchar (200) NOT NULL,
+    profile_value varchar (200) NOT NULL
+);
+
+-----------------------------------------------------------------------------
+-- notifications
+-----------------------------------------------------------------------------
+CREATE TABLE notifications
+(   
+    id serial,
+    notification_type varchar (200) NOT NULL,
+    notification_charset varchar (60) NOT NULL,
+    notification_language varchar (60) NOT NULL,
+    subject varchar (250) NOT NULL,
+    text varchar NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by integer NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by integer NOT NULL,
+    PRIMARY KEY(id)
+);  
+
+-----------------------------------------------------------------------------
+-- faq_item 
+-----------------------------------------------------------------------------
+CREATE TABLE faq_item
+(
+    id serial, 
+    f_name VARCHAR (200) NOT NULL,
+    f_language_id SMALLINT NOT NULL,
+    f_subject VARCHAR (200),
+    state_id SMALLINT NOT NULL,
+    category_id SMALLINT NOT NULL,
+    f_keywords TEXT,
+    f_field1 TEXT,
+    f_field2 TEXT,
+    f_field3 TEXT,
+    f_field4 TEXT,
+    f_field5 TEXT,
+    f_field6 TEXT,
+    free_key1 VARCHAR (80),
+    free_value1 VARCHAR (200),
+    free_key2 VARCHAR (80),
+    free_value2 VARCHAR (200),
+    free_key3 VARCHAR (80),
+    free_value3 VARCHAR (200),
+    free_key4 VARCHAR (80),
+    free_value4 VARCHAR (200),
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (f_name)
+);
+
+-----------------------------------------------------------------------------
+-- faq_language
+-----------------------------------------------------------------------------
+CREATE TABLE faq_language
+(
+    id serial, 
+    name VARCHAR (200) NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+);
+
+-----------------------------------------------------------------------------
+-- faq_history
+-----------------------------------------------------------------------------
+CREATE TABLE faq_history
+(
+    id serial,
+    name VARCHAR (200) NOT NULL,
+    item_id INTEGER NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id)
+);
+
+-----------------------------------------------------------------------------
+-- faq_category
+-----------------------------------------------------------------------------
+CREATE TABLE faq_category
+(
+    id serial,
+    name VARCHAR (200) NOT NULL,
+    comments VARCHAR (220) NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+);
+
+-----------------------------------------------------------------------------
+-- faq_state
+-----------------------------------------------------------------------------
+CREATE TABLE faq_state
+(
+    id serial,
+    name VARCHAR (200) NOT NULL,
+    type_id INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+);
+
+-----------------------------------------------------------------------------
+-- faq_state_type
+-----------------------------------------------------------------------------
+CREATE TABLE faq_state_type
+(
+    id serial,
+    name VARCHAR (200) NOT NULL,
+    PRIMARY KEY(id), 
+    UNIQUE (name)
+);  
+
+
 ----------------------------------------------------------------------------
 -- session
 ----------------------------------------------------------------------------
